open_storage

Function open_storage 

pub async fn open_storage(
    name: &str,
    base_dir: Option<&str>,
) -> ChatResult<Connection>
Open a file-backed SQLite connection.

If base_dir is provided, the database is stored under that directory. Otherwise it is created in the current working directory.